@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2003-2021 Edgewall Software
+# Copyright (C) 2003-2023 Edgewall Software
 # Copyright (C) 2003-2005 Jonas Borgström <jonas@edgewall.com>
 # Copyright (C) 2005 Christopher Lenz <cmlenz@gmx.de>
 # All rights reserved.
@@ -288,6 +288,12 @@ class TestCaseSetup(unittest.TestCase):
         self.fixture = fixture
 
 
+def makeSuite(testCaseClass, suiteClass=unittest.TestSuite):
+    loader = unittest.TestLoader()
+    loader.suiteClass = suiteClass
+    return loader.loadTestsFromTestCase(testCaseClass)
+
+
 # -- Database utilities
 
 def get_dburi():
@@ -528,19 +534,20 @@ def rmtree(path):
         if function not in (os.unlink, os.remove):
             raise
         e = excinfo[1]
-        if isinstance(e, PermissionError):
-            mode = os.stat(path).st_mode
-            os.chmod(path, mode | 0o666)
-            try:
-                function(path)
-            except Exception:
-                # print "%d: %s %o" % (retry, path, os.stat(path).st_mode)
-                if retry > 10:
-                    raise
-                time.sleep(0.1)
-                onerror(function, path, excinfo, retry + 1)
-        else:
+        if not isinstance(e, PermissionError):
             raise
+        mode = os.stat(path).st_mode
+        os.chmod(path, mode | 0o666)
+        try:
+            function(path)
+        except Exception:
+            # print "%d: %s %o" % (retry, path, os.stat(path).st_mode)
+            if retry > 10:
+                raise
+            time.sleep(0.1)
+        else:
+            return
+        onerror(function, path, excinfo, retry + 1)
     if os.name == 'nt' and isinstance(path, bytes):
         # Use unicode characters in order to allow non-ansi characters
         # on Windows.
