@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2005-2021 Edgewall Software
+# Copyright (C) 2005-2023 Edgewall Software
 # Copyright (C) 2005-2006 Christopher Lenz <cmlenz@gmx.de>
 # All rights reserved.
 #
@@ -636,6 +636,10 @@ class Request(object):
         if user is not None:
             return to_unicode(user)
 
+    @property
+    def request_path(self):
+        return self.href(self.path_info)
+
     @property
     def response_started(self):
         return self._write is not None
